@@ -9,5 +9,6 @@ utils::globalVariables(c(
   'channel',
   'dbThreshold',
   'histbreaks',
-  'normality'
+  'normality',
+  'type'
 ))
